@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 # FiwixOS _VERSION_ installation script.
-# Copyright 2018-2024, Jordi Sanfeliu. All rights reserved.
+# Copyright 2018-2025, Jordi Sanfeliu. All rights reserved.
 # Distributed under the terms of the Fiwix License.
 #
 
@@ -101,7 +101,7 @@ welcome() {
 	echo "			to the installation of FiwixOS $OSVERSION"
 	echo "			    for the i386 architecture"
 	echo
-	echo "		    Copyright (c) 2018-2024 by Jordi Sanfeliu"
+	echo "		    Copyright (c) 2018-2025 by Jordi Sanfeliu"
 	echo "			      <jordi@fibranet.cat>"
 	echo
 	echo
@@ -699,6 +699,9 @@ create_devices() {
 	makedev ttyS2 c 4 66 660 root
 	makedev ttyS3 c 4 67 660 root
 
+	makedev ptmx c 5 2 666 tty
+	mkdir dev/pts ; chmod 755 dev/pts
+
 	makedev lp0 c 6 0 660 lp
 
 	makedev psaux c 10 1 660 root
@@ -711,9 +714,6 @@ create_devices() {
 
 	makedev fb0 c 29 0 660 root
 	ln -s /dev/fb0 dev/fb
-
-	mkfifo dev/fifo
-	chmod 666 dev/fifo
 }
 
 create_system_dirs() {
@@ -874,9 +874,6 @@ if [ -f ~/.bashrc ] ; then
 fi
 
 # User specific environment and startup programs
-PATH=$PATH:/usr/local/bin:/root/bin
-
-export PATH
 
 EOF
 
@@ -888,6 +885,10 @@ if [ -f /etc/bashrc ]; then
 	. /etc/bashrc
 fi
 
+# User specific environment
+PATH=\$HOME/bin:\$PATH
+export PATH
+
 # User specific aliases and functions
 
 alias rm='rm -i'
@@ -899,25 +900,26 @@ EOF
 	nump=1
 	if [ "$separateboot" = 0 ] ; then
 		cat <<EOF >etc/fstab
-${TARGET}${nump}	/boot	ext2	ro,defaults	0 0
+${TARGET}${nump}	/boot		ext2	ro,defaults	1 2
 EOF
 		nump=$(expr $nump + 1)
 	fi
 
 
 	cat <<EOF >>etc/fstab
-${TARGET}${nump}	/	ext2	defaults	1 1
+${TARGET}${nump}	/		ext2	defaults	1 1
 EOF
 	nump=$(expr $nump + 1)
 
 	if [ "$nparts" -gt 2 ] ; then
 		cat <<EOF >>etc/fstab
-${TARGET}${nump}	/home	ext2	rw,defaults	0 0
+${TARGET}${nump}	/home		ext2	rw,defaults	1 2
 EOF
 	fi
 
 	cat <<EOF >>etc/fstab
-none		/proc	proc	defaults,noauto	0 0
+none		/proc		proc	defaults,noauto	0 0
+none		/dev/pts/	devpts	defaults	0 0
 EOF
 
 	cat <<EOF >>etc/motd
@@ -1056,7 +1058,7 @@ EOF
 # menu.lst generated during the FiwixOS installation
 #
 # FiwixOS
-# Copyright (C) 2018-2024 Jordi Sanfeliu <jordi@fibranet.cat>
+# Copyright (C) 2018-2025 Jordi Sanfeliu <jordi@fibranet.cat>
 #
 # GRUB configuration file
 #
